/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 * 
 * Contributor(s):
 * 
 * $Id: PersonImpl.java,v 1.1 2004/08/16 10:48:50 slobodan Exp $
 */

package transactionsDiscRack.business.person;

 
import transactionsDiscRack.data.person.*;
import transactionsDiscRack.data.disc.DiscDO;
import transactionsDiscRack.spec.Person;
import transactionsDiscRack.business.TransactionsDiscRackBusinessException;

import com.lutris.appserver.server.sql.DatabaseManagerException;
import com.lutris.appserver.server.sql.ObjectIdException;
import com.lutris.dods.builder.generator.query.DataObjectException;
import org.enhydra.dods.exceptions.AssertionDataObjectException;
import com.lutris.appserver.server.sql.DBTransaction;
import org.enhydra.dods.*;
        
/**
 * Represents a person. 
 */
public class PersonImpl implements Person,java.io.Serializable {
    /**
     * The DO of the Person.
     */
    protected PersonDO myDO = null;
    
    /**
     * The public constructor.
     */
    public PersonImpl() throws TransactionsDiscRackBusinessException {
	DBTransaction trans = null;
        try {
	    try{ 
		trans = DODS.getDatabaseManager().createTransaction();
	    }catch(Exception ex){
		throw new DatabaseManagerException("Error creating transaction!", ex);
	    }
	    prep(trans);
            this.myDO = PersonDO.createVirgin(trans);
        } catch(DatabaseManagerException ex) {
            throw new TransactionsDiscRackBusinessException("Error creating empty person", ex);
        } catch(ObjectIdException ex) {
            throw new TransactionsDiscRackBusinessException("Error creating object ID for person", ex);
        }
    }
    
    /** The public constructor
     *
     * @param thePerson The data object of the person.
     */
    public PersonImpl(PersonDO thePerson) {
        this.myDO = thePerson; 
    }
    
    /**
     * Gets the object id for the person
     *
     * @return the object id.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getHandle()
        throws TransactionsDiscRackBusinessException {
        try {
            return this.myDO.getHandle();
        } catch(DatabaseManagerException ex) {
            throw new TransactionsDiscRackBusinessException("Error getting handle for person", ex);
        }
    }
    
    /**
     * Gets the login name for the person
     *
     * @return the login name.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getLogin() 
        throws TransactionsDiscRackBusinessException {
        try {
            return myDO.getLogin();
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error getting user's login name", ex);
        }
    }
    
    /**
     * Gets the password for the person
     *
     * @return the password.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getPassword() 
        throws TransactionsDiscRackBusinessException {
        try {
            return myDO.getPassword();
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error getting user's password", ex);
        }
    }
    
    /**
     * Gets the firstname for the person
     *
     * @return the firstname.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getFirstname() 
        throws TransactionsDiscRackBusinessException {
        try {
            return myDO.getFirstname();
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error getting user's first name", ex);
        }
    }
    
    /**
     * Gets the lastname for the person
     *
     * @return the lastname.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getLastname() 
        throws TransactionsDiscRackBusinessException {
        try {
            return myDO.getLastname();
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error getting user's last name", ex);
        }
    }
    
    /**
     * Sets the login name for the person.
     *
     * @param login  login name.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setLogin(String login) 
        throws TransactionsDiscRackBusinessException {
        try {
            myDO.setLogin(login);
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error setting user's login name", ex);
        }
    }
    
    /**
     * Sets the password for the person.
     *
     * @param password
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setPassword(String password) 
        throws TransactionsDiscRackBusinessException {
        try {
            myDO.setPassword(password);
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error setting user's password", ex);
        }
    }
    
    /**
     * Sets the firstname for the person.
     *
     * @param firstname
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setFirstname(String firstname) 
        throws TransactionsDiscRackBusinessException {
        try {
            myDO.setFirstname(firstname);
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error setting user's first name", ex);
        }
    }
    
    /**
     * Sets the lastname for the person.
     *
     * @param lastname
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setLastname(String lastname) 
        throws TransactionsDiscRackBusinessException {
        try {
            myDO.setLastname(lastname);
        } catch(DataObjectException ex) {
            throw new TransactionsDiscRackBusinessException("Error setting user's last name", ex);
        }
    }
    
    private void prep(DBTransaction trans) {
	try {
	    PersonQuery query = new PersonQuery(trans);
	    query.setQueryHandle("0");
	    query.requireUniqueInstance();
	    query.getNextDO();
	} catch (Exception exc){}
    }
    /**
     * Commits all changes to the database.
     *
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public void save() throws TransactionsDiscRackBusinessException, AssertionDataObjectException {
        try {
            this.myDO.save();
	    this.myDO.get_transaction().commit();
        } 
        catch (AssertionDataObjectException ex) {
            throw new AssertionDataObjectException("Read-only table: DML operations not allowed", ex);
        } 
        catch(Exception ex) {
            throw new TransactionsDiscRackBusinessException("Error saving person", ex);
        }
    }
    public void dbtRelease() {
	myDO.get_transaction().release();
    }
}
